# my_decimal
### my_decimal - это функция Python, которая принимает числовое выражение и возвращает его в формате строки с округлением до трех знаков после запятой.
#### это нужно для того чтобы не возникали такие ситуации
```python
print(0,1+0,2)
# Вывод: 0.30000000000000004
```
***
## Установка
*Функция my_decimal не требует установки дополнительных библиотек. Просто напишите в консоли*
> `pip install my-decimal`
***
## Пример использования

1. ### без использования дополнительных модулей
```python
num1 = 0.1
num2 = 0.2

result = num1 + num2

print(f'{result:.3f}')
# Вывод: 0.300
```

2. ### c модулем decimal
```python
from decimal import Decimal

num1 = Decimal('0.1')
num2 = Decimal('0.2')

result = num1 + num2

print(result)

# Вывод: 0.3

```
3. ### c модулем my_decimal
```python
from my_decimal import my_decimal

num1 = 0.1
num2 = 0.2

result = my_decimal(num1+num2)

print(result)  
# Вывод: 0.300
```
## как мы видим использование модуля my_decimal самое удобное

#### Функция принимает числовое выражение и возвращает его в формате строки с округлением до трех знаков после запятой.
***
## Важно
*Функция my_decimal предполагает, что входное выражение является числом. При передаче нечисловых значений будут возникать ошибки.*

***
### Автор

Автор: k0ng999